[![Build Status](https://github.com/allen-cell-animated/abm-colony-collection/workflows/build/badge.svg)](https://github.com/allen-cell-animated/abm-colony-collection/actions?query=workflow%3Abuild)
[![Codecov](https://img.shields.io/codecov/c/gh/allen-cell-animated/abm-colony-collection?token=YSWZXHUW1R)](https://codecov.io/gh/allen-cell-animated/abm-colony-collection)
[![Lint Status](https://github.com/allen-cell-animated/abm-colony-collection/workflows/lint/badge.svg)](https://github.com/allen-cell-animated/abm-colony-collection/actions?query=workflow%3Alint)
[![Documentation](https://github.com/allen-cell-animated/abm-colony-collection/workflows/documentation/badge.svg)](https://allen-cell-animated.github.io/abm-colony-collection/)
[![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
